# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mudkip']

package_data = \
{'': ['*'], 'mudkip': ['_static/*']}

install_requires = \
['Sphinx>=5.1.1,<6.0.0',
 'click>=8.1.3,<9.0.0',
 'furo>=2022.6.21,<2023.0.0',
 'jupyter-nbextensions-configurator>=0.5.0,<0.6.0',
 'livereload>=2.6.3,<3.0.0',
 'myst-nb>=0.16.0,<0.17.0',
 'notebook>=6.4.12,<7.0.0',
 'pydata-sphinx-theme>=0.9.0,<0.10.0',
 'sphinx-rtd-theme>=1.0.0,<2.0.0',
 'sphinxcontrib-mermaid>=0.7.1,<0.8.0',
 'tomlkit>=0.7.0',
 'watchdog>=2.1.9,<3.0.0']

extras_require = \
{':sys_platform == "win32"': ['colorama']}

entry_points = \
{'console_scripts': ['mudkip = mudkip.cli:main']}

setup_kwargs = {
    'name': 'mudkip',
    'version': '0.8.0',
    'description': 'A friendly Sphinx wrapper',
    'long_description': '# Mudkip\n\n[![GitHub Actions](https://github.com/vberlier/mudkip/workflows/CI/badge.svg)](https://github.com/vberlier/mudkip/actions)\n[![PyPI](https://img.shields.io/pypi/v/mudkip.svg)](https://pypi.org/project/mudkip/)\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mudkip.svg)](https://pypi.org/project/mudkip/)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)\n\n> A friendly [Sphinx](https://www.sphinx-doc.org/en/master/) wrapper.\n\nMudkip is a small wrapper around [Sphinx](https://www.sphinx-doc.org/en/master/) that bundles essential tools and extensions, providing everything needed for building rich documentation for Python projects.\n\n```bash\n$ mudkip --help\nUsage: mudkip [OPTIONS] COMMAND [ARGS]...\n\n  A friendly Sphinx wrapper.\n\nOptions:\n  --version  Show the version and exit.\n  --help     Show this message and exit.\n\nCommands:\n  build    Build documentation.\n  clean    Remove output directory.\n  develop  Start development server.\n  init     Initialize documentation.\n  test     Test documentation.\n```\n\n## Features\n\nMudkip intends to provide an out-of-the-box solution for most Python projects. The command-line utility lets you build and check your documentation, launch a development server with live reloading, run doctests and more!\n\nMudkip enables the following Sphinx extensions:\n\n- [`sphinx.ext.autodoc`](http://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html) for generating documentation from docstrings\n- [`sphinx.ext.napoleon`](https://www.sphinx-doc.org/en/master/usage/extensions/napoleon.html) for Google-style and NumPy-style docstring support\n- [`sphinx.ext.doctest`](https://www.sphinx-doc.org/en/master/usage/extensions/doctest.html) for doctest support\n- [`sphinx.ext.autosectionlabel`](https://www.sphinx-doc.org/en/master/usage/extensions/autosectionlabel.html) for referencing sections with their title\n- [`sphinx.ext.intersphinx`](https://www.sphinx-doc.org/en/master/usage/extensions/intersphinx.html) for linking to other projects’ documentation\n- [`sphinx.ext.githubpages`](https://www.sphinx-doc.org/en/master/usage/extensions/githubpages.html) when deploying to GitHub Pages\n- [`myst_parser`](https://myst-parser.readthedocs.io/en/latest/) for markdown support\n- [`myst_nb`](https://myst-nb.readthedocs.io/en/latest/) for Jupyter notebook support\n- [`sphinxcontrib.mermaid`](https://github.com/mgaitan/sphinxcontrib-mermaid) for [Mermaid](https://mermaid-js.github.io/mermaid/) graphs and flowcharts\n\n## Installation\n\nThe package can be installed with `pip`.\n\n```bash\n$ pip install mudkip\n```\n\n## Getting started\n\nYou can forget everything about `sphinx-quickstart`, `conf.py` and intimidating Makefiles. After installing the package, no need to configure anything you can run the `develop` command right away and start writing docs.\n\n```bash\n$ mudkip develop\nWatching "docs"...\nServer running on http://localhost:5500\n```\n\nThe command will create the "docs" directory if it doesn\'t already exist and launch a development server with live reloading. If you create an `index.rst` file and open the link in your browser, you\'ll see that mudkip uses the [Read the Docs](https://github.com/rtfd/sphinx_rtd_theme) theme by default.\n\n> Note that mudkip enables the [`myst_parser`](https://myst-parser.readthedocs.io/en/latest/) extension, allowing you to use both reStructuredText and markdown files. You can create an `index.md` file if you want to use markdown instead of reStructuredText.\n\nPress `Ctrl+C` at any time to exit.\n\n### Building and checking documentation\n\nThe `build` command invokes the [`dirhtml`](https://www.sphinx-doc.org/en/master/usage/builders/index.html#sphinx.builders.dirhtml.DirectoryHTMLBuilder) builder and builds your documentation. By default, the generated files are in "docs/\\_build".\n\n```bash\n$ mudkip build\n```\n\nRunning the command with the `--check` or `-c` flag will exit with code `1` if Sphinx reports any error or warning.\n\n```bash\n$ mudkip build --check\n```\n\nThe `--check` flag also makes sure that there are no broken links by running the [`linkcheck`](https://www.sphinx-doc.org/en/master/usage/builders/index.html#sphinx.builders.linkcheck.CheckExternalLinksBuilder) builder on your documentation. You can disable this with the `--skip-broken-links` flag.\n\nThe `build` command also features a really handy flag if you\'re deploying the documentation to GitHub Pages. The `--update-gh-pages` flag will invoke Sphinx with the [`sphinx.ext.githubpages`](https://www.sphinx-doc.org/en/master/usage/extensions/githubpages.html) extension and then force push the output directory to the `gh-pages` branch of your repository.\n\n```bash\n$ mudkip build --update-gh-pages\n```\n\nThe remote branch will be created if it doesn\'t already exist.\n\n### Running doctests\n\nMudkip enables the [`sphinx.ext.doctest`](https://www.sphinx-doc.org/en/master/usage/extensions/doctest.html) extension, making it possible to test interactive code examples. You can try it out by adding the following code snippet to your `index` document:\n\n```rst\n.. doctest::\n\n    >>> import this\n    The Zen of Python, by Tim Peters\n    <BLANKLINE>\n    Beautiful is better than ugly.\n    ...\n```\n\nThe `test` command will run the code example and make sure that the output matches the documentation.\n\n```bash\n$ mudkip test\nTesting "docs"...\n\nDocument: index\n---------------\n1 items passed all tests:\n   1 tests in default\n1 tests in 1 items.\n1 passed and 0 failed.\nTest passed.\n\nDoctest summary\n===============\n    1 test\n    0 failures in tests\n    0 failures in setup code\n    0 failures in cleanup code\n\nPassed.\n```\n\n### Using Jupyter notebooks\n\nThe [`myst-nb`](https://myst-nb.readthedocs.io/en/latest/) extension provides support for Jupyter notebooks. This means that in addition to `.rst` and `.md` files, Sphinx will also generate pages for `.ipynb` files.\n\nThe `develop` command can launch the Jupyter notebook in the "docs" directory and open it in your browser with the `--notebook` or `-n` flag.\n\n```bash\n$ mudkip develop --notebook\nWatching "docs"...\nServer running on http://localhost:5500\nNotebook running on http://localhost:8888/?token=5e64df6...\n```\n\nNotebooks are executed during the build process. The `--check` flag will make sure that there are no uncaught exceptions in any cell.\n\n### Integration with npm and yarn\n\nMudkip can help you go beyond traditional Sphinx themes by running npm scripts for you and integrate with the build process of a custom front-end. If your docs contain a `package.json` file, Mudkip will run Sphinx and then invoke the appropriate npm script using your preferred npm client.\n\n```bash\n$ mudkip build\n```\n\nHere, Mudkip would try to run either `npm run build` or `yarn build` before exiting the command. Similarly, `mudkip clean` would try to run either `npm run clean` or `yarn clean`.\n\n```bash\n$ mudkip develop\n```\n\nThe `develop` command will try to run one of the following scripts: `develop`, `dev`, `start` or `serve`. If you don\'t have a dedicated script to run your project in development mode, Mudkip will simply execute the `build` script after running Sphinx each time you make a modification.\n\n## Configuration\n\nMudkip doesn\'t really require any configuration but you can change some of the default settings with command-line options or a configuration file.\n\nFor example, when running a command, you can set the `--preset` or `-p` option to `furo` if you want to use the [Furo](https://pradyunsg.me/furo/) theme instead of the default [Read the Docs](https://github.com/rtfd/sphinx_rtd_theme) theme.\n\n```\n$ mudkip build --preset furo\n```\n\nIt\'s also possible to change the default source and output directories with the `--source-dir` and `--output-dir` options respectively.\n\n```\n$ mudkip build --source-dir path/to/docs --output-dir path/to/output\n```\n\nPassing these options to every single command can become tedious so you can use a configuration file to save your custom settings.\n\nRunning the `init` command will either add a `[tool.mudkip]` section to your `pyproject.toml` or create a `mudkip.toml` file with some basic configuration.\n\n```bash\n$ mudkip init\n```\n\n### Available options\n\n- `preset`\n\n  **default**: `"rtd"`\n\n  Presets configure Mudkip and Sphinx to enable specific features. The `rtd`, `furo` and `alabaster` presets enable the development server and configure Sphinx to use the `dirhtml` builder. The `rtd` preset changes the html theme to the [Read the Docs](https://github.com/rtfd/sphinx_rtd_theme) theme and the `furo` preset to the [Furo](https://pradyunsg.me/furo/) theme.\n\n  The `xml` preset configures Sphinx to use the `xml` builder. This is useful for more advanced use-cases when you have a separate static site generator that can process a hierarchy of docutils documents.\n\n- `source_dir`\n\n  **default**: `"docs"`\n\n  This is the directory containing the source files for your documentation. Sphinx is configured to use it as its source directory and when the development server is enabled, Mudkip will watch the directory for changes to rebuild your documentation.\n\n- `output_dir`\n\n  **default**: `"docs/_build"`\n\n  The output directory is where Sphinx will output the generated files. This is also the directory served by the development server.\n\n- `base_url`\n\n  **default**: `None`\n\n  The base url used by Sphinx when building the documentation. You can use it to specify a custom domain when deploying to GitHub Pages and make sure Sphinx generates the appropriate `CNAME` file.\n\n- `repository`\n\n  **default**: The `repository` field in `pyproject.toml`\n\n  The repository url of the remote when updating GitHub Pages.\n\n  If you\'re not using [poetry](https://poetry.eustace.io/), you will need to set it manually.\n\n- `verbose`\n\n  **default**: `false`\n\n  This option can also be enabled on the command-line with the `--verbose` flag. Setting it to `true` will tell Mudkip to display the entire Sphinx output as well as the Jupyter notebook output when running the `develop` command with the `--notebook` flag.\n\n- `project_name`\n\n  **default**: The name of the project you\'re documenting in `pyproject.toml`\n\n  If you\'re not using [poetry](https://poetry.eustace.io/), you will need to set it manually.\n\n- `project_dir`\n\n  **default**: The value of the `project_name` option\n\n  Mudkip will watch the Python files in your project directory when using the development server. This enables live reloading even when you\'re editing docstrings.\n\n- `title`\n\n  **default**: The value of the `project_name` option\n\n  The project title used by Sphinx when building the documentation.\n\n- `copyright`\n\n  **default**: The current year followed by the value of the `author` option\n\n  The copyright notice used by Sphinx when building the documentation.\n\n- `author`\n\n  **default**: The concatenated list of authors in `pyproject.toml`\n\n  If you\'re not using [poetry](https://poetry.eustace.io/), you will need to set it manually.\n\n- `version`\n\n  **default**: The first two numbers of the `release` option\n\n  The version used by Sphinx when building the documentation.\n\n- `release`\n\n  **default**: The project version in `pyproject.toml`\n\n  If you\'re not using [poetry](https://poetry.eustace.io/), you will need to set it manually.\n\n- `override`\n\n  **default**: An empty dictionary\n\n  The `override` option lets you override sphinx configuration directly. You can use it to specify a custom theme or a logo for instance.\n\n- `section_label_depth`\n\n  Enables `sphinx.ext.autosectionlabel` and sets the `autosectionlabel_maxdepth` option.\n\n## Contributing\n\nContributions are welcome. Make sure to first open an issue discussing the problem or the new feature before creating a pull request. The project uses [poetry](https://python-poetry.org/).\n\n```bash\n$ poetry install\n```\n\nThe code follows the [black](https://github.com/psf/black) code style.\n\n```bash\n$ poetry run black mudkip\n```\n\n---\n\nLicense - [MIT](https://github.com/vberlier/mudkip/blob/master/LICENSE)\n',
    'author': 'Valentin Berlier',
    'author_email': 'berlier.v@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/vberlier/mudkip',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
